/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 15/10/22.
//

#include "fggl/script/lua/module.hpp"
#include "fggl/script/lua/engine.hpp"

namespace fggl::script::lua {

	static assets::AssetTypeID is_lua(std::filesystem::path path) {
		if ( path.extension() == ".lua" ) {
			return SCRIPT_LUA;
		}
		return assets::INVALID_ASSET_TYPE;
	}

	void Lua::setup(fggl::services::Generator *generator) {
		auto adapted = generator->getLazy<assets::CheckinAdapted>();
		adapted->setLoader(MIME_LUA, assets::NEEDS_CHECKIN, is_lua);
	}

	void Lua::wireServices(services::ModuleBinder &binder) {
		binder.bind<ScriptProvider>().to<LuaScriptProvider, fggl::filesystem::Locator>();
	}

}